/* IMPORT */
import colors from 'tiny-colors';
import Addon from './addon.js';
import { identity, stripAnsi } from '../utils.js';
/* MAIN */
class Logger extends Addon {
    constructor() {
        /* VARIABLES */
        super(...arguments);
        this.indentationLevel = 0;
        this.indentation = '  ';
    }
    /* API */
    indent() {
        this.indentationLevel += 1;
    }
    dedent() {
        this.indentationLevel -= 1;
    }
    group(name, fn) {
        this.print(colors.bold(name.toUpperCase()));
        this.indent();
        this.print();
        fn();
        this.print();
        this.dedent();
    }
    print(message = '') {
        const colorize = this.bin.metadata.colors ? identity : stripAnsi;
        console.log(colorize(`${this.indentation.repeat(this.indentationLevel)}${message}`));
    }
    table(rows) {
        const raws = rows.map(row => row.map(stripAnsi));
        const maxLengths = raws[0].map((_, j) => Math.max(...raws.map((_, i) => raws[i][j].length)));
        rows.forEach((row, i) => {
            const line = row.map((value, j) => {
                const paddingLength = Math.max(0, 1 + maxLengths[j] - raws[i][j].length);
                const padding = ' '.repeat(paddingLength);
                return `${value}${padding}`;
            }).join(' ');
            this.print(line);
        });
    }
}
/* EXPORT */
export default Logger;
