/* IMPORT */
import stripAnsi from 'ansi-purge';
import levenshtein from 'tiny-levenshtein';
/* MAIN */
const camelCase = (() => {
    const dividerRe = /[_.\s-]+/g;
    const prefixRe = /^[_.\s-]+/g;
    const upperDigitRe = /\d+[\p{Alpha}\p{N}_]/gu;
    const upperDividerRe = /[_.\s-]+[\p{Alpha}\p{N}_]/gu;
    const toUpperCase = (str) => str.toUpperCase();
    return (str) => {
        return str.trim().toLowerCase().replace(prefixRe, '').replace(upperDigitRe, toUpperCase).replace(upperDividerRe, toUpperCase).replace(dividerRe, '');
    };
})();
const castArray = (value) => {
    return Array.isArray(value) ? value : [value];
};
const defer = (fn) => {
    setTimeout(fn, 0);
};
const getClosest = (values, value, maxDistance = 3) => {
    if (!values.length)
        return;
    const distances = values.map(other => levenshtein(value, other));
    const minDistance = Math.min(...distances);
    if (minDistance > maxDistance)
        return;
    const minDistanceIndex = distances.indexOf(minDistance);
    const closest = values[minDistanceIndex];
    return closest;
};
const identity = (value) => {
    return value;
};
const isArray = (value) => {
    return Array.isArray(value);
};
const isUndefined = (value) => {
    return value === undefined;
};
const sum = (numbers) => {
    return numbers.reduce((acc, value) => acc + value, 0);
};
/* EXPORT */
export { camelCase, castArray, defer, getClosest, identity, isArray, isUndefined, stripAnsi, sum };
